Security Advisories (3)
CPANSA-Plack-2015-0202 (2015-02-02)

Fixed a possible directory traversal with Plack::App::File on Win32.

CPANSA-Plack-2014-0801 (2014-08-01)

Plack::App::File would previously strip trailing slashes off provided paths. This in combination with the common pattern of serving files with Plack::Middleware::Static could allow an attacker to bypass a whitelist of generated files

CPANSA-Plack-2013-0131 (2013-01-31)

Fixed directory traversal bug in Plack::App::File on win32 environments

NAME

Plack::Handler::HTTP::Server::PSGI - adapter for HTTP::Server::PSGI

SYNOPSIS

% plackup -s HTTP::Server::PSGI \
    --host 127.0.0.1 --port 9091 --timeout 120

BACKWARD COMPATIBLITY

Since Plack 0.99_22 this handler doesn't support preforking configuration i.e. --max-workers. Use Starman or Starlet if you need preforking PSGI web server.

CONFIGURATIONS

host

Host the server binds to. Defaults to all interfaces.

port

Port number the server listens on. Defaults to 8080.

timeout

Number of seconds a request times out. Defaults to 300.

max-reqs-per-child

Number of requests per worker to process. Defaults to 100.

AUTHOR

Kazuho Oku

Tatsuhiko Miyagawa

SEE ALSO

Plack HTTP::Server::PSGI